@@ -7,13 +7,13 @@ use Data::MARC::Field008::Utils qw(check_government_publication check_index
 	check_item_form check_map_cartographic_material_type check_map_projection
 	check_map_relief check_map_special_format);
 use Error::Pure qw(err);
-use Error::Pure::Utils qw(err_get);
+use Error::Pure::Utils qw(clean err_get);
 use Mo qw(build is);
 use Mo::utils 0.22 qw(check_length_fix);
 
 our $STRICT = 1;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 has form_of_item => (
 	is => 'ro',
@@ -81,6 +81,8 @@ sub BUILD {
 				defined $self->raw ? ('Raw string', $self->raw) : (),
 			;
 		}
+	} else {
+		clean();
 	}
 
 	return;
@@ -426,6 +428,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
