@@ -5,13 +5,13 @@ use warnings;
 
 use Data::MARC::Field008::Utils qw(check_item_form);
 use Error::Pure qw(err);
-use Error::Pure::Utils qw(err_get);
+use Error::Pure::Utils qw(clean err_get);
 use Mo qw(build is);
 use Mo::utils 0.22 qw(check_length_fix check_required check_strings);
 
 our $STRICT = 1;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 has form_of_item => (
 	is => 'ro',
@@ -37,6 +37,8 @@ sub BUILD {
 				defined $self->raw ? ('Raw string', $self->raw) : (),
 			;
 		}
+	} else {
+		clean();
 	}
 
 	return;
@@ -192,6 +194,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
