@@ -8,13 +8,13 @@ use Data::MARC::Field008::Utils qw(check_item_form
 	check_music_format check_music_literary_text check_music_parts
 	check_music_transposition_and_arrangement check_target_audience);
 use Error::Pure qw(err);
-use Error::Pure::Utils qw(err_get);
+use Error::Pure::Utils qw(clean err_get);
 use Mo qw(build is);
 use Mo::utils 0.22 qw(check_length_fix check_required);
 
 our $STRICT = 1;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 has accompanying_matter => (
 	is => 'ro',
@@ -89,6 +89,8 @@ sub BUILD {
 				defined $self->raw ? ('Raw string', $self->raw) : (),
 			;
 		}
+	} else {
+		clean();
 	}
 
 	return;
@@ -465,6 +467,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
